@@ -22,6 +22,9 @@ from flask_discord_interactions.models import (
     ActionRow,
     Button,
     ButtonStyles,
+    TextInput,
+    TextStyles,
+    Modal,
     ComponentType,
     SelectMenu,
     SelectMenuOption,
@@ -105,6 +108,9 @@ __all__ = [
     "ActionRow",
     "Button",
     "ButtonStyles",
+    "TextInput",
+    "TextStyles",
+    "Modal",
     "SelectMenu",
     "SelectMenuOption",
     "Client",
