@@ -1,5 +1,5 @@
 from dataclasses import dataclass
-from typing import Any, List, Union
+from typing import Any, List, Optional, Union
 import inspect
 import itertools
 import warnings
@@ -68,6 +68,10 @@ class Context(LoadableDataclass):
     message
         The message that the invoked components are attached to.
         Only available on component interactions.
+    locale
+        The selected language of the invoking user.
+    guild_locale
+        The guild's preferred locale, if invoked in a guild
     """
 
     author: Union[Member, User] = None
@@ -86,6 +90,8 @@ class Context(LoadableDataclass):
     channels: List[Channel] = None
     roles: List[Role] = None
     message: Message = None
+    locale: Optional[str] = None
+    guild_locale: Optional[str] = None
 
     app: Any = None
     discord: Any = None
@@ -123,6 +129,8 @@ class Context(LoadableDataclass):
             command_id=data.get("data", {}).get("id"),
             custom_id=data.get("data", {}).get("custom_id") or "",
             target_id=data.get("data", {}).get("target_id"),
+            locale=data.get("locale"),
+            guild_locale=data.get("guild_locale"),
         )
 
         result.data = data
@@ -388,8 +396,7 @@ class Context(LoadableDataclass):
 
         updated = requests.patch(
             self.followup_url(message),
-            json=updated.dump_followup(),
-            headers=self.auth_headers,
+            **updated.dump_multipart(),
         )
         updated.raise_for_status()
 
@@ -407,9 +414,7 @@ class Context(LoadableDataclass):
         if not self.app or self.app.config["DONT_REGISTER_WITH_DISCORD"]:
             return
 
-        response = requests.delete(
-            self.followup_url(message), headers=self.auth_headers
-        )
+        response = requests.delete(self.followup_url(message))
         response.raise_for_status()
 
     def send(self, message):
@@ -427,9 +432,7 @@ class Context(LoadableDataclass):
 
         message = Message.from_return_value(message)
 
-        message = requests.post(
-            self.followup_url(), headers=self.auth_headers, **message.dump_multipart()
-        )
+        message = requests.post(self.followup_url(), **message.dump_multipart())
         message.raise_for_status()
         return message.json()["id"]
 
@@ -572,7 +575,7 @@ class AsyncContext(Context):
             return
 
         async with self.session.post(
-            self.followup_url(), headers=self.auth_headers, **message.dump_multipart()
+            self.followup_url(), **message.dump_multipart()
         ) as message:
             return (await message.json())["id"]
 
